@@ -1,4 +1,4 @@
-## Copyright (C) 2005 Michel D. Schmid   <michaelschmid@users.sourceforge.net>
+## Copyright (C) 2005 Michel D. Schmid  <michaelschmid@users.sourceforge.net>
 ##
 ##
 ## This program is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 ##
 ## @end deftypefn
 
-## @seealso{}
+## @seealso{__mae}
 
 ## Author: Michel D. Schmid
 
